{% for invoice in data %}
invoice:               {{ invoice.number }}
paid:                  {{ invoice.paid_already }}
submitted:             {{ invoice.submitted_on or '' }}
payout due in:         {{ invoice.payout_due_date_relative }}
inv submittal due in:  {% if invoice.submitted_on %}N/A{% else %}{{ invoice.submittal_due_from_now_delta.days }} days on {{ invoice.submittal_due_date.strftime("%m-%d") }}{% endif %}
{% endfor -%}
